<?php

//
//	ForumInfo
//
//		ForumInfo serves as a client-side cache of forum names
//		Call ForumInfo::get(forumid), and use setName(forumname),
//		wherever you have both peices of information. Then add the
//		object back to the cache by calling ForumInfo::set(forumObject)
//
final class ForumInfo {         
	public static function all() {
		return array_values(@$_SESSION['ForumInfo']);
	}
	public static function get($id) {
        if(isset($_SESSION['ForumInfo'][$id])) {
            return $_SESSION['ForumInfo'][$id];
        }     
        return new ForumInfo($id);
    }
    
    public static function set($forum) {
        $_SESSION['ForumInfo'][$forum->getId()] = $forum;
    }
	
	//
	//	Hit api_forumlist to get all values we need
	//
	public static function refreshAll() {
		$json = json_decode(VBApiClient::instance()->call_cached('api_forumlist', array(), array()), true);
		self::populateForums($json);
	}	
		
	public static function populateForums($forumbits) {
		if(!empty($forumbits['forumid'])) {			
			$forum = ForumInfo::get($forumbits['forumid']);
			$forum->setName($forumbits['title_clean']);
			$forum->setSubscribed(@$forumbits['subscribed'] == 1);
			ForumInfo::set($forum);
			self::populateForums(@$forumbits['subforums']);
		} else if (!empty($forumbits)) {
			foreach($forumbits as $forumbits_f) {
				self::populateForums(@$forumbits_f);
			}
		}
	}
    
    private $id;
	private $name;
    private $subscribed = null;
	private $subscribed_thread = null;
	
	public function getId() {
		return $this->id;
	}
	public function getName() {
		return $this->name;
	}
	public function setName($name) {
		$this->name = $name;
	}
    public function isSubscribed() {
		return $this->subscribed;
    }
    public function setSubscribed($sub) {
        $this->subscribed = $sub;
    }
	public function hasSubscribedThread() {
		return $this->subscribed_thread;
    }
    public function setHasSubscribedThread($sub) {
        $this->subscribed_thread = $sub;
    }
    
    private function __construct($id) {
        $this->id = $id;
	}
}

?>